==> ra-sdk-0.0.1-20191224.022434-2-sources.jar: com/xdja/ra/bean/UpdateApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:28
 * @Description:
 */
public class UpdateApplyInfo {
    /**
     * 必须	申请原因
     */
    private String applyReason;
    /**
     * 必须	申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销
     */
    private Integer applyStatus;
    /**
     * 必须	申请更新后的证书DN
     */
    private String certDn;
    /**
     * 必须	证书有效期
     */
    private Integer certValidity;
    /**
     * 必须	证书生效时间
     */
    private String effectiveTime;
    /**
     * 必须	待更新的证书的加密证书SN
     */
    private String encSn;
    /**
     * 必须	证书失效时间
     */
    private String failureTime;
    /**
     * 必须	更新申请创建时间
     */
    private String gmtCreate;
    /**
     * 必须	是否更新密钥
     */
    private Boolean isUpdateKey;
    /**
     * 必须	密钥算法
     */
    private String keyAlg;
    /**
     * 必须	待更新的当前证书的剩余时间
     */
    private Integer leftValidity;
    /**
     * 必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     *必须	证书签名算法
     */
    private String signAlg;
    /**
     *必须	待更新的证书的签名证书SN
     */
    private String signSn;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getFailureTime() {
        return failureTime;
    }

    public void setFailureTime(String failureTime) {
        this.failureTime = failureTime;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Boolean getUpdateKey() {
        return isUpdateKey;
    }

    public void setUpdateKey(Boolean updateKey) {
        isUpdateKey = updateKey;
    }

    public String getKeyAlg() {
        return keyAlg;
    }

    public void setKeyAlg(String keyAlg) {
        this.keyAlg = keyAlg;
    }

    public Integer getLeftValidity() {
        return leftValidity;
    }

    public void setLeftValidity(Integer leftValidity) {
        this.leftValidity = leftValidity;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    @Override
    public String toString() {
        return "UpdateApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", applyStatus=" + applyStatus +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", effectiveTime='" + effectiveTime + '\'' +
                ", encSn='" + encSn + '\'' +
                ", failureTime='" + failureTime + '\'' +
                ", gmtCreate='" + gmtCreate + '\'' +
                ", isUpdateKey=" + isUpdateKey +
                ", keyAlg='" + keyAlg + '\'' +
                ", leftValidity=" + leftValidity +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", signSn='" + signSn + '\'' +
                '}';
    }
}

==> ra-sdk-1.0.5-20200922.061634-2-sources.jar: com/xdja/ra/bean/UpdateApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:28
 * @Description:
 */
public class UpdateApplyInfo {
    /**
     * 必须	申请原因
     */
    private String applyReason;
    /**
     * 必须	申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销
     */
    private Integer applyStatus;
    /**
     * 必须	申请更新后的证书DN
     */
    private String certDn;
    /**
     * 必须	证书有效期
     */
    private Integer certValidity;
    /**
     * 必须	证书生效时间
     */
    private String effectiveTime;
    /**
     * 必须	待更新的证书的加密证书SN
     */
    private String encSn;
    /**
     * 必须	证书失效时间
     */
    private String failureTime;
    /**
     * 必须	更新申请创建时间
     */
    private String gmtCreate;
    /**
     * 必须	是否更新密钥
     */
    private Boolean isUpdateKey;
    /**
     * 必须	密钥算法
     */
    private String keyAlg;
    /**
     * 必须	待更新的当前证书的剩余时间
     */
    private Integer leftValidity;
    /**
     * 必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     *必须	证书签名算法
     */
    private String signAlg;
    /**
     *必须	待更新的证书的签名证书SN
     */
    private String signSn;
    /**
     *必须	模板名称
     */
    private String tempName;
    /**
     *必须	模板编号
     */
    private String tempNo;
    /**
     *必须	模板扩展参数
     */
    private String tempParas;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getFailureTime() {
        return failureTime;
    }

    public void setFailureTime(String failureTime) {
        this.failureTime = failureTime;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Boolean getUpdateKey() {
        return isUpdateKey;
    }

    public void setUpdateKey(Boolean updateKey) {
        isUpdateKey = updateKey;
    }

    public String getKeyAlg() {
        return keyAlg;
    }

    public void setKeyAlg(String keyAlg) {
        this.keyAlg = keyAlg;
    }

    public Integer getLeftValidity() {
        return leftValidity;
    }

    public void setLeftValidity(Integer leftValidity) {
        this.leftValidity = leftValidity;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        return "UpdateApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", applyStatus=" + applyStatus +
                ", certDn='" + certDn + '\'' +
                ", certValidity=" + certValidity +
                ", effectiveTime='" + effectiveTime + '\'' +
                ", encSn='" + encSn + '\'' +
                ", failureTime='" + failureTime + '\'' +
                ", gmtCreate='" + gmtCreate + '\'' +
                ", isUpdateKey=" + isUpdateKey +
                ", keyAlg='" + keyAlg + '\'' +
                ", leftValidity=" + leftValidity +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", signSn='" + signSn + '\'' +
                ", tempName='" + tempName + '\'' +
                ", tempNo='" + tempNo + '\'' +
                ", tempParas='" + tempParas + '\'' +
                '}';
    }
}
